## What Talc Does

Talc provides tooling to reliably test LLM based systems. It provides a simple API and command line tool for generating testing sets based on a knowledge base, and the ability to run tests and evaluate the results.

Visit our [homepage](https://talc.ai) to sign up or find our docs on [GitHub](https://github.com/Talc-AI/talc-docs/wiki).